@@ -18,9 +18,23 @@ var ExtCommonUtils = {
 	
 	get browserURI() 
 	{
-		var handler = Components.classes['@mozilla.org/commandlinehandler/general-startup;1?type=browser'].getService(Components.interfaces.nsICmdLineHandler);
-		return handler.chromeUrlForTask;
+		if (!this._browserURI) {
+			var uri = this.getPref('browser.chromeURL');
+			if (!uri) {
+				try {
+					var handler = Components.classes['@mozilla.org/commandlinehandler/general-startup;1?type=browser'].getService(Components.interfaces.nsICmdLineHandler);
+					uri = handler.chromeUrlForTask;
+				}
+				catch(e) {
+				}
+			}
+			if (uri.charAt(uri.length-1) == '/')
+				uri = uri.replace(/chrome:\/\/([^\/]+)\/content\//, 'chrome://$1/content/$1.xul');
+			this._browserURI = uri;
+		}
+		return this._browserURI;
 	},
+	_browserURI : null,
   
 	get isMail() 
 	{
@@ -851,7 +865,9 @@ var ExtCommonUtils = {
 		}
 
 		FP.appendFilters(nsIFilePicker.filterAll);
-		FP.show();
+
+		var flag = FP.show();
+		if (flag & nsIFilePicker.returnCancel) return null;
 
 		try {
 			return FP.file.QueryInterface(Components.interfaces.nsILocalFile);
@@ -1379,7 +1395,7 @@ var ExtCommonUtils = {
 		if (!targetWindow || Components.lookupMethod(targetWindow, 'top').call(targetWindow) == window)
 			targetWindow = window._content;
 
-		var selection = targetWindow.getSelection();
+		var selection = Components.lookupMethod(targetWindow, 'getSelection').call(targetWindow);
 		if (!selection || !selection.toString()) return nodes;
 
 
