@@ -18,7 +18,7 @@ var ExtFunc = {
 	XHTMLNS : 'http://www.w3.org/1999/xhtml',
 	XLinkNS : 'http://www.w3.org/1999/xlink',
 	XULNS   : 'http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul',
-	EXNS    : 'http://white.sakura.ne.jp/~piro/ctxextensions',
+	EXNS    : 'http://piro.sakura.ne.jp/ctxextensions',
  
 //=========================== Executable Functions ============================
 // @\ 
